#[non_exhaustive]pub enum PlanError {
ExactOutcomeHasDiagnostic,
MissingDiagnostic {
subject: String,
code: DiagnosticCode,
},
}Expand description
Invalid conversion plan invariant.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ExactOutcomeHasDiagnostic
An exact outcome was incorrectly linked to a loss diagnostic.
MissingDiagnostic
A non-exact outcome referenced a diagnostic missing from the plan.