ExportAdapter

Trait ExportAdapter 

pub trait ExportAdapter {
    type Output;

    // Required method
    fn plan(
        &self,
        application: &Application,
        target: &TargetProfile,
    ) -> Result<ConversionPlan<Self::Output>, PlanError>;
}
Plans one neutral application for a native target model.

Required Associated Types

type Output

Native target candidate returned by this adapter.

Required Methods

fn plan( &self, application: &Application, target: &TargetProfile, ) -> Result<ConversionPlan<Self::Output>, PlanError>

Builds a validated candidate plan for the explicit target profile.

Errors

Returns PlanError when the adapter violates plan invariants.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors